==> haskell-rio-orphans-0.1.1.0-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio-orphans
version: 0.1.1.0
id: rio-orphans-0.1.1.0-8EVoW0v0ZEz7mgXCs9WIYL
key: rio-orphans-0.1.1.0-8EVoW0v0ZEz7mgXCs9WIYL
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/rio#readme
synopsis: Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>
category: Control
abi: b8d40c3f54b8fb9992a62d479f0219ed
exposed: True
exposed-modules:
    RIO.Orphans
hidden-modules: Paths_rio_orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/rio-orphans-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/rio-orphans-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/rio-orphans-0.1.1.0
hs-libraries: HSrio-orphans-0.1.1.0-8EVoW0v0ZEz7mgXCs9WIYL
depends:
    base-4.12.0.0 exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    fast-logger-3.0.0-GjpcBX1YPXdAemBNe1iSUl
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh
    monad-logger-0.3.31-2uHNfQ0m1QOLOSbPX0Tvy0
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    rio-0.1.12.0-FVrInZuoZCBFj7h6GfiM8d
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
haddock-interfaces: /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html: /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-orphans-0.1.1.0-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio-orphans
version: 0.1.1.0
id: rio-orphans-0.1.1.0-IulsI4iMoq88Fzbsr7nbn
key: rio-orphans-0.1.1.0-IulsI4iMoq88Fzbsr7nbn
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/rio#readme
synopsis: Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>
category: Control
abi: 84e2605767d50d81f49cfe8bfd2d5237
exposed: True
exposed-modules:
    RIO.Orphans
hidden-modules: Paths_rio_orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/rio-orphans-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/rio-orphans-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/rio-orphans-0.1.1.0
hs-libraries: HSrio-orphans-0.1.1.0-IulsI4iMoq88Fzbsr7nbn
depends:
    base-4.12.0.0 exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    fast-logger-3.0.0-GjpcBX1YPXdAemBNe1iSUl
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh
    monad-logger-0.3.31-ImvkmNSkLZ43nmZqqVd6b0
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    rio-0.1.12.0-FVrInZuoZCBFj7h6GfiM8d
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
haddock-interfaces: /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html: /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
